@@ -2,8 +2,8 @@
 Scrapy - a screen scraping framework written in Python
 """
 
-version_info = (0, 10, 4, 'dev')
-__version__ = "0.10.4"
+version_info = (0, 12, 0)
+__version__ = "0.12.0"
 
 import sys, os, warnings
 
@@ -14,14 +14,6 @@ if sys.version_info < (2,5):
 # ignore noisy twisted deprecation warnings
 warnings.filterwarnings('ignore', category=DeprecationWarning, module='twisted')
 
-# prevents noisy (and innocent) dropin.cache errors when loading spiders from
-# egg files using the old Spider Manager. TODO: Remove for Scrapy 0.11
-try:
-    from twisted.python.zippath import ZipPath
-    ZipPath.setContent = lambda x, y: None
-except ImportError: # to avoid making setup.py depend on Twisted
-    pass
-
 # monkey patches to fix external library issues
 from scrapy.xlib import twisted_250_monkeypatches, urlparse_monkeypatches
 
@@ -41,4 +33,5 @@ except ImportError:
     pass
 else:
     optional_features.add('boto')
-__version__ += '.2364'
+
+__version__ = '.'.join(map(str, version_info)) + '.2550'
\ No newline at end of file
