@@ -6,6 +6,7 @@ See documentation in docs/topics/shell.rst
 
 from scrapy.command import ScrapyCommand
 from scrapy.shell import Shell
+from scrapy import log
 
 class Command(ScrapyCommand):
 
@@ -21,6 +22,11 @@ class Command(ScrapyCommand):
     def long_desc(self):
         return "Interactive console for scraping the given url"
 
+    def add_options(self, parser):
+        ScrapyCommand.add_options(self, parser)
+        parser.add_option("-c", dest="code",
+            help="evaluate the code in the shell, print the result and exit")
+
     def update_vars(self, vars):
         """You can use this function to update the Scrapy objects that will be
         available in the shell
@@ -29,6 +35,12 @@ class Command(ScrapyCommand):
 
     def run(self, args, opts):
         url = args[0] if args else None
-        shell = Shell(self.crawler, update_vars=self.update_vars, inthread=True)
-        shell.start(url=url).addBoth(lambda _: self.crawler.stop())
+        shell = Shell(self.crawler, update_vars=self.update_vars, inthread=True, \
+            code=opts.code)
+        def err(f):
+            log.err(f, "Shell error")
+            self.exitcode = 1
+        d = shell.start(url=url)
+        d.addErrback(err)
+        d.addBoth(lambda _: self.crawler.stop())
         self.crawler.start()
